@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -174,6 +174,14 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] ETC_UTC = new String[] {
+               "Hora Coordenada Universal",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] America_Eastern = new String[] {
                "Hora padr\u00e3o Oriental",
                "",
@@ -1265,16 +1273,7 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
-            { "UTC",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "UTC", ETC_UTC },
             { "Asia/Aden", Arabian },
             { "America/Cuiaba", Amazon },
             { "timezone.excity.Europe/San_Marino", "S\u00e3o Marinho" },
@@ -1307,6 +1306,7 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "America/Indiana/Petersburg", America_Eastern },
             { "Asia/Yerevan", Armenia },
             { "Europe/Brussels", Europe_Central },
+            { "JST", Japan },
             { "Europe/Warsaw", Europe_Central },
             { "Pacific/Yap", Truk },
             { "timezone.excity.Africa/Djibouti", "Jibuti" },
@@ -1329,8 +1329,10 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Dubai", Gulf },
             { "Europe/Isle_of_Man", GMT },
+            { "BET", Brasilia },
             { "America/Araguaina", Brasilia },
             { "timezone.excity.Pacific/Easter", "Ilha da P\u00e1scoa" },
+            { "ACT", Australia_Central },
             { "Asia/Novosibirsk", Novosibirsk },
             { "America/Argentina/Salta", Argentina },
             { "Africa/Tunis", Europe_Central },
@@ -1363,6 +1365,7 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Yerevan", "Erevan" },
             { "Africa/Asmera", Africa_Eastern },
             { "Europe/Busingen", Europe_Central },
+            { "AET", Australia_Eastern },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "Africa/Malabo", Africa_Western },
             { "Europe/Skopje", Europe_Central },
@@ -1382,16 +1385,6 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "America/Anguilla", Atlantic },
             { "Asia/Dili", East_Timor },
             { "Africa/Bamako", GMT },
-            { "Europe/Saratov",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Pacific/Wallis", Wallis },
             { "Europe/Gibraltar", Europe_Central },
             { "Africa/Conakry", GMT },
@@ -1430,16 +1423,6 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Europe/Helsinki", Europe_Eastern },
             { "Asia/Beirut", Europe_Eastern },
             { "timezone.excity.Asia/Baghdad", "Bagdade" },
-            { "Pacific/Bougainville",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.America/Montevideo", "Montevideu" },
             { "Africa/Sao_Tome", Africa_Western },
             { "Indian/Chagos", Indian_Ocean },
@@ -1456,6 +1439,7 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "America/Yellowknife", America_Mountain },
             { "Pacific/Enderbury", Phoenix_Islands },
             { "America/Juneau", Alaska },
+            { "CNT", Newfoundland },
             { "America/Indiana/Vevay", America_Eastern },
             { "timezone.excity.Europe/Monaco", "M\u00f3naco" },
             { "timezone.excity.Asia/Hebron", "Hebron" },
@@ -1483,6 +1467,7 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Europe/Samara", Samara },
             { "Indian/Christmas", Christmas },
             { "America/Antigua", Atlantic },
+            { "NET", Armenia },
             { "Pacific/Gambier", Gambier },
             { "America/Inuvik", America_Mountain },
             { "America/Iqaluit", America_Eastern },
@@ -1531,6 +1516,7 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "timezone.excity.America/Argentina/Tucuman", "Tucum\u00e1n" },
             { "America/Indiana/Knox", America_Central },
             { "timezone.excity.Asia/Saigon", "Cidade de Ho Chi Minh" },
+            { "PLT", Pakistan },
             { "America/North_Dakota/Beulah", America_Central },
             { "Africa/Accra", GMT },
             { "timezone.excity.Africa/Niamey", "Niamei" },
@@ -1538,6 +1524,7 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "America/Maceio", Brasilia },
             { "Pacific/Apia", Apia },
             { "Pacific/Niue", Niue },
+            { "CST", America_Central },
             { "Australia/Lord_Howe", Lord_Howe },
             { "Europe/Dublin",
                 new String[] {
@@ -1553,6 +1540,7 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "MST7MDT", America_Mountain },
             { "America/Monterrey", America_Central },
             { "America/Nassau", America_Eastern },
+            { "SST", Solomon },
             { "America/Jamaica", America_Eastern },
             { "Asia/Bishkek", Kyrgystan },
             { "Atlantic/Stanley", Falkland },
@@ -1561,6 +1549,7 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Indian/Mahe", Seychelles },
             { "Asia/Aqtobe", Kazakhstan_Western },
             { "timezone.excity.Pacific/Efate", "Efate" },
+            { "CTT", China },
             { "timezone.excity.Asia/Aqtobe", "Aqtobe" },
             { "Asia/Vladivostok", Vladivostok },
             { "Africa/Libreville", Africa_Western },
@@ -1572,6 +1561,7 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Pacific/Marquesas", Marquesas },
             { "America/Aruba", Atlantic },
             { "America/North_Dakota/Center", America_Central },
+            { "PNT", America_Mountain },
             { "America/Cayman", America_Eastern },
             { "Asia/Ulaanbaatar", Mongolia },
             { "Asia/Baghdad", Arabian },
@@ -1580,6 +1570,7 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "timezone.excity.America/Port-au-Prince", "Port-au-Prince" },
             { "Europe/San_Marino", Europe_Central },
             { "America/Indiana/Tell_City", America_Central },
+            { "BST", Bangladesh },
             { "America/Tijuana", America_Pacific },
             { "Pacific/Saipan", Chamorro },
             { "SystemV/YST9", Gambier },
@@ -1590,9 +1581,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Damascus", Europe_Eastern },
+            { "MIT", Apia },
             { "America/Argentina/San_Luis", Argentina_Western },
             { "America/Santiago", Chile },
             { "Asia/Baku", Azerbaijan },
+            { "ART", Europe_Eastern },
             { "America/Argentina/Ushuaia", Argentina },
             { "Atlantic/Reykjavik", GMT },
             { "Africa/Brazzaville", Africa_Western },
@@ -1607,32 +1600,13 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Asia/Bangkok", Indochina },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
             { "Atlantic/Madeira", Europe_Western },
-            { "Antarctica/Palmer",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "America/Thunder_Bay", America_Eastern },
             { "timezone.excity.America/Port_of_Spain", "Porto de Espanha" },
             { "Africa/Addis_Ababa", Africa_Eastern },
+            { "AST", Alaska },
             { "Europe/Uzhgorod", Europe_Eastern },
             { "America/Indiana/Marengo", America_Eastern },
             { "America/Creston", America_Mountain },
-            { "America/Punta_Arenas",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.Europe/Helsinki", "Hels\u00ednquia" },
             { "America/Mexico_City", America_Central },
             { "Antarctica/Vostok", Vostok },
@@ -1646,6 +1620,7 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Atlantic/South_Georgia", South_Georgia },
             { "Europe/Lisbon", Europe_Western },
             { "Asia/Harbin", China },
+            { "PRT", Atlantic },
             { "Europe/Oslo", Europe_Central },
             { "Asia/Novokuznetsk", Krasnoyarsk },
             { "timezone.excity.America/Bahia_Banderas", "Bahia Banderas" },
@@ -1665,6 +1640,7 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Africa/Kampala", Africa_Eastern },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
             { "timezone.excity.Asia/Kuwait", "Koweit" },
+            { "PST", America_Pacific },
             { "SystemV/EST5", America_Eastern },
             { "America/Edmonton", America_Mountain },
             { "Europe/Podgorica", Europe_Central },
@@ -1745,26 +1721,18 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Asia/Kamchatka", Kamchatka },
             { "Africa/Harare", Africa_Central },
             { "America/Nome", Alaska },
+            { "NST", New_Zealand },
             { "timezone.excity.Africa/Nairobi", "Nairobi" },
             { "Europe/Tallinn", Europe_Eastern },
             { "Africa/Khartoum", Africa_Central },
             { "Africa/Johannesburg", Africa_Southern },
+            { "EAT", Africa_Eastern },
             { "Africa/Bangui", Africa_Western },
             { "timezone.excity.Asia/Singapore", "Singapura" },
             { "Europe/Belgrade", Europe_Central },
             { "Africa/Bissau", GMT },
             { "timezone.excity.America/Cayman", "Caim\u00e3o" },
             { "Asia/Tehran", Iran },
-            { "Europe/Astrakhan",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Juba", Africa_Eastern },
             { "America/Campo_Grande", Amazon },
             { "America/Belem", Brasilia },
@@ -1781,6 +1749,7 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "America/Whitehorse", America_Pacific },
             { "Pacific/Noumea", New_Caledonia },
             { "Asia/Tbilisi", Georgia },
+            { "ECT", Europe_Central },
             { "America/Montreal", America_Eastern },
             { "timezone.excity.America/Anguilla", "Anguila" },
             { "Asia/Makassar", Indonesia_Central },
@@ -1796,16 +1765,6 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Kuala_Lumpur", Malaysia },
             { "Asia/Thimphu", Bhutan },
-            { "Asia/Famagusta",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Asia/Rangoon", Myanmar },
             { "Europe/Bratislava", Europe_Central },
             { "timezone.excity.Indian/Christmas", "Ilha do Natal" },
@@ -1815,17 +1774,8 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Indian/Cocos", Cocos },
             { "Pacific/Tongatapu", Tonga },
             { "SystemV/YST9YDT", Alaska },
-            { "Europe/Ulyanovsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "America/Merida", America_Central },
+            { "CAT", Africa_Central },
             { "America/St_Kitts", Atlantic },
             { "Arctic/Longyearbyen", Europe_Central },
             { "timezone.excity.Asia/Kuala_Lumpur", "Kuala Lumpur" },
@@ -1839,16 +1789,6 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.America/Cancun", "Cancun" },
             { "timezone.excity.Europe/Kaliningrad", "Caliningrado" },
-            { "Asia/Srednekolymsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "America/North_Dakota/New_Salem", America_Central },
             { "Asia/Anadyr", Anadyr },
             { "Australia/Melbourne", Australia_Eastern },
@@ -1861,16 +1801,7 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Europe/Vatican", Europe_Central },
             { "timezone.excity.Indian/Cocos", "Ilhas Cocos" },
             { "Asia/Amman", Europe_Eastern },
-            { "Etc/UTC",
-                new String[] {
-                    "Hora Coordenada Universal",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "Etc/UTC", ETC_UTC },
             { "SystemV/AST4ADT", Atlantic },
             { "America/Toronto", America_Eastern },
             { "Asia/Singapore", Singapore },
